@@ -17,9 +17,9 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 
-__id__        = "$Id: J2SE-access-bridge.py 1543 2006-10-12 00:33:48Z wwalker $"
-__version__   = "$Revision: 1543 $"
-__date__      = "$Date: 2006-10-11 20:33:48 -0400 (Wed, 11 Oct 2006) $"
+__id__        = "$Id: J2SE-access-bridge.py 2140 2007-03-07 20:04:06Z richb $"
+__version__   = "$Revision: 2140 $"
+__date__      = "$Date: 2007-03-07 15:04:06 -0500 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -31,7 +31,6 @@ import orca_state
 import keybindings
 import settings
 import speech
-import util
 import rolenames
 import Accessibility
 import speechgenerator
@@ -168,13 +167,13 @@ class Script(default.Script):
                 # search the layered pane for a popup menu
                 child = event.source.child(i)
                 if child.role == rolenames.ROLE_LAYERED_PANE:
-                    popup = util.findByRole(child, rolenames.ROLE_POPUP_MENU, False)
+                    popup = self.findByRole(child, rolenames.ROLE_POPUP_MENU, False)
                     if len(popup) > 0:
                         # set the locus of focus to the armed menu item
-                        item = util.findByRole(popup[0], rolenames.ROLE_MENU_ITEM, False)
-                        for j in range(0, len(item)):
-                            if item[j].state.count(Accessibility.STATE_ARMED):
-                                orca.setLocusOfFocus(event, item[j])
+                        items = self.findByRole(popup[0], rolenames.ROLE_MENU_ITEM, False)
+                        for item in items:
+                            if item.state.count(Accessibility.STATE_ARMED):
+                                orca.setLocusOfFocus(event, item)
                                 return
         
 
@@ -238,7 +237,9 @@ class Script(default.Script):
                 # or if the item doesn't have SELECTED state, but SELECTABLE and
                 # it was selected.
                 #
-                if util.isSameObject (selectedItem, orca_state.locusOfFocus):
+                if orca_state.activeScript and \
+                   orca_state.activeScript.isSameObject(selectedItem,  \
+                                                    orca_state.locusOfFocus):
                     if (orca_state.locusOfFocus.state.count(Accessibility.STATE_SELECTED) != 0 \
                                 and not orca_state.locusOfFocus.was_selected)   \
                         or (orca_state.locusOfFocus.state.count(Accessibility.STATE_SELECTED) == 0 \
@@ -283,7 +284,7 @@ class Script(default.Script):
         # This case is for LISTs which contain labels as items
         # (see Open dialog lists).
         #
-        if util.isSameObject (obj, orca_state.locusOfFocus):
+        if orca_state.activeScript.isSameObject(obj, orca_state.locusOfFocus):
             if obj.role == rolenames.ROLE_LABEL:
                 self.updateBraille(orca_state.locusOfFocus)
                 speech.speakUtterances(self.speechGenerator.getSpeech(orca_state.locusOfFocus, True))
