@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 1933 2007-01-17 19:32:35Z wwalker $"
-__version__   = "$Revision: 1933 $"
-__date__      = "$Date: 2007-01-17 14:32:35 -0500 (Wed, 17 Jan 2007) $"
+__id__        = "$Id: braillegenerator.py 2126 2007-03-06 21:35:17Z richb $"
+__version__   = "$Revision: 2126 $"
+__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -37,7 +37,6 @@ import debug
 import orca_state
 import rolenames
 import settings
-import util
 
 from orca_i18n import _                     # for gettext support
 
@@ -165,7 +164,7 @@ class BrailleGenerator:
         if settings.brailleVerbosityLevel == settings.VERBOSITY_LEVEL_VERBOSE:
             text = ""
 
-            result = util.getAcceleratorAndShortcut(obj)
+            result = self._script.getAcceleratorAndShortcut(obj)
 
             accelerator = result[0]
             #shortcut = result[1]
@@ -223,7 +222,7 @@ class BrailleGenerator:
         try:
             minimumIncrement = value.minimumIncrement
         except:
-            pass
+            minimumIncrement = 0.0
 
         if minimumIncrement == 0.0:
             minimumIncrement = (value.maximumValue - value.minimumValue) \
@@ -293,10 +292,10 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForValue(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -332,10 +331,10 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForAnimation", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
-        text = util.appendString(text, obj.description, ": ")
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, obj.description, ": ")
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -375,15 +374,15 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForCheckBox", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "<x>")
+            text = self._script.appendString(text, "<x>")
         else:
-            text = util.appendString(text, "< >")
+            text = self._script.appendString(text, "< >")
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -405,18 +404,18 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForCheckMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "<x>")
+            text = self._script.appendString(text, "<x>")
         else:
-            text = util.appendString(text, "< >")
+            text = self._script.appendString(text, "< >")
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForRole(obj))
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForRole(obj))
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -456,12 +455,12 @@ class BrailleGenerator:
         regions = []
 
         focusedRegionIndex = 0
-        label = util.getDisplayedLabel(obj)
+        label = self._script.getDisplayedLabel(obj)
         if label and (len(label) > 0):
             regions.append(braille.Region(label + " "))
             focusedRegionIndex = 1
 
-        displayedText = util.getDisplayedText(obj)
+        displayedText = self._script.getDisplayedText(obj)
         if displayedText:
             regions.append(braille.Region(displayedText))
 
@@ -585,15 +584,15 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForIcon", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.image:
             description = obj.image.imageDescription
             if len(description):
-                text = util.appendString(text, description)
+                text = self._script.appendString(text, description)
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -660,13 +659,13 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForMenu", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, rolenames.getBrailleForRoleName(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, rolenames.getBrailleForRoleName(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -703,12 +702,12 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -732,7 +731,7 @@ class BrailleGenerator:
 
         regions = []
 
-        textRegion = braille.Text(obj, util.getDisplayedLabel(obj))
+        textRegion = braille.Text(obj, self._script.getDisplayedLabel(obj))
         regions.append(textRegion)
 
         eol = braille.Region(" $l")
@@ -769,12 +768,12 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForPageTab", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -828,17 +827,17 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         # In Java, some push buttons don't have label and text.
         # In this case, we'll add to presentation the object description,
         # if exists.
         #
         if (not text) and (obj.description):
-            text = util.appendString(text, obj.description)
+            text = self._script.appendString(text, obj.description)
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -860,22 +859,22 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForRadioButton", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         # In Java, some toggle buttons don't have label and text.
         # In this case, we'll add to presentation the object description,
         # if exists.
         #
         if (not text) and (obj.description):
-            text = util.appendString(text, obj.description)
+            text = self._script.appendString(text, obj.description)
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "&=y")
+            text = self._script.appendString(text, "&=y")
         else:
-            text = util.appendString(text, "& y")
+            text = self._script.appendString(text, "& y")
 
-        text = util.appendString(text, self._getTextForRole(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -897,18 +896,18 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForRadioMenuItem", obj)
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
-        text = util.appendString(text, util.getDisplayedText(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedText(obj))
 
         if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = util.appendString(text, "&=y")
+            text = self._script.appendString(text, "&=y")
         else:
-            text = util.appendString(text, "& y")
+            text = self._script.appendString(text, "& y")
 
         if obj == orca_state.locusOfFocus:
-            text = util.appendString(text, self._getTextForRole(obj))
-            text = util.appendString(text, self._getTextForAvailability(obj))
-            text = util.appendString(text,
+            text = self._script.appendString(text, self._getTextForRole(obj))
+            text = self._script.appendString(text, self._getTextForAvailability(obj))
+            text = self._script.appendString(text,
                                       self._getTextForAccelerator(obj),
                                       "")
 
@@ -965,11 +964,11 @@ class BrailleGenerator:
         regions = []
 
         text = ""
-        text = util.appendString(text, util.getDisplayedLabel(obj))
+        text = self._script.appendString(text, self._script.getDisplayedLabel(obj))
         # Ignore the text on the slider.
-        #text = util.appendString(text, util.getDisplayedText(obj))
-        text = util.appendString(text, self._getTextForValue(obj))
-        text = util.appendString(text, self._getTextForRole(obj))
+        #text = self._script.appendString(text, self._script.getDisplayedText(obj))
+        text = self._script.appendString(text, self._getTextForValue(obj))
+        text = self._script.appendString(text, self._getTextForRole(obj))
 
         regions = []
         componentRegion = braille.Component(obj, text)
@@ -1053,10 +1052,10 @@ class BrailleGenerator:
 
         if len(regions) == 0:
             regions = self._getDefaultBrailleRegions(
-                              util.getRealActiveDescendant(obj))
+                              self._script.getRealActiveDescendant(obj))
         else:
-            [cellRegions, focusRegion] = \
-              self._getDefaultBrailleRegions(util.getRealActiveDescendant(obj))
+            [cellRegions, focusRegion] = self._getDefaultBrailleRegions(\
+                self._script.getRealActiveDescendant(obj))
             regions[0].extend(cellRegions)
 
         # [[[TODO: WDW - HACK attempt to determine if this is a node;
@@ -1068,7 +1067,7 @@ class BrailleGenerator:
             else:
                 regions[0].append(braille.Region(" " + _("collapsed")))
 
-        level = util.getNodeLevel(obj)
+        level = self._script.getNodeLevel(obj)
         if level >= 0:
             regions[0].append(braille.Region(" " + _("TREE LEVEL %d") \
                                              % (level + 1)))
@@ -1199,14 +1198,14 @@ class BrailleGenerator:
         self._debugGenerator("_getBrailleRegionsForTerminal", obj)
 
         title = None
-        frame = util.getFrame(obj)
+        frame = self._script.getFrame(obj)
         if frame:
             title = frame.name
         if not title:
-            title = util.getDisplayedLabel(obj)
+            title = self._script.getDisplayedLabel(obj)
 
         text = title
-        text = util.appendString(text, rolenames.getBrailleForRoleName(obj))
+        text = self._script.appendString(text, rolenames.getBrailleForRoleName(obj))
 
         regions = []
         regions.append(braille.Region(text))
@@ -1408,8 +1407,8 @@ class BrailleGenerator:
 
                 # Announce the label and text of the object in the hierarchy.
                 #
-                label = util.getDisplayedLabel(parent)
-                text = util.getDisplayedText(parent)
+                label = self._script.getDisplayedLabel(parent)
+                text = self._script.getDisplayedText(parent)
                 regions.append(braille.Region(" "))
                 result = self.getBrailleRegions(parent, False)
                 regions.extend(result[0])
@@ -1423,7 +1422,7 @@ class BrailleGenerator:
             # we add the label to the overall context.]]]
             #
             if parent.role == rolenames.ROLE_FILLER:
-                label = util.getDisplayedLabel(parent)
+                label = self._script.getDisplayedLabel(parent)
                 if label and len(label) and not label.isspace():
                     regions.append(braille.Region(" "))
                     result = self.getBrailleRegions(parent, False)
