@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py,v 1.75 2006/12/08 17:12:48 lmonsanto Exp $"
-__version__   = "$Revision: 1.75 $"
-__date__      = "$Date: 2006/12/08 17:12:48 $"
+__id__        = "$Id: Evolution.py 2174 2007-03-14 19:33:59Z richb $"
+__version__   = "$Revision: 2174 $"
+__date__      = "$Date: 2007-03-14 15:33:59 -0400 (Wed, 14 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -35,7 +35,6 @@ import orca.braille as braille
 import orca.orca_state as orca_state
 import orca.speech as speech
 import orca.settings as settings
-import orca.util as util
 import orca.chnames as chnames
 
 from orca.orca_i18n import _ # for gettext support
@@ -116,7 +115,7 @@ class Script(default.Script):
         self.inputEventHandlers["toggleReadMailHandler"] = \
             input_event.InputEventHandler(
                 Script.toggleReadMail,
-                _("Toggle whether we present new mail if we not not the active script."))
+                _("Toggle whether we present new mail if we are not the active script."))
 
     def getKeyBindings(self):
         """Defines the new key binding for this script. Setup the default
@@ -190,7 +189,7 @@ class Script(default.Script):
                         self.textAttrsToDictionary(charAttributes[0])
                     weight = charDict.get('weight')
                     if weight and weight == '800':
-                        text = util.getDisplayedText(label)
+                        text = self.getDisplayedText(label)
 
                         # Only speak the screen label if we haven't already
                         # done so.
@@ -217,7 +216,7 @@ class Script(default.Script):
             # events for the same label. If we've already handled this
             # label, then just ignore it.
             #
-            text = util.getDisplayedText(label)
+            text = self.getDisplayedText(label)
             if text and not self.setupLabels.has_key(label):
                 # Most of the Setup Assistant screens have a useful piece
                 # of text starting with the word "Please". We want to speak
@@ -239,9 +238,9 @@ class Script(default.Script):
         - panel: the Setup Assistant panel.
         """
 
-        allLabels = util.findByRole(panel, rolenames.ROLE_LABEL)
-        for i in range(0, len(allLabels)):
-            self.speakSetupAssistantLabel(allLabels[i])
+        allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
+        for label in allLabels:
+            self.speakSetupAssistantLabel(label)
 
     def readPageTab(self, tab):
         """Speak/Braille the given page tab. The speech verbosity is set
@@ -290,7 +289,7 @@ class Script(default.Script):
 
         return hrs + ' ' + mins + ' ' + suffix
 
-    def textLines(self):
+    def readTextLines(self):
         """This an iterator that produces elements of the form:
         [SayAllContext, acss], where SayAllContext has the text to be
         spoken and acss is an ACSS instance for speaking the text.  We
@@ -307,7 +306,7 @@ class Script(default.Script):
             panel = atspi.Accessible.makeAccessible(accPanel)
             accTextObj = panel.accessible.getChildAtIndex(0)
             textObj = atspi.Accessible.makeAccessible(accTextObj)
-            for [context, acss] in util.textLines(textObj):
+            for [context, acss] in self.textLines(textObj):
                 yield [context, acss]
 
     def sayAll(self, inputEvent):
@@ -323,9 +322,7 @@ class Script(default.Script):
 
         debug.println(self.debugLevel, "evolution.sayAll.")
         if orca_state.locusOfFocus and orca_state.locusOfFocus.text:
-            #for [context, acss] in self.textLines():
-            #    print context.utterance
-            speech.sayAll(self.textLines(),
+            speech.sayAll(self.readTextLines(),
                           self.__sayAllProgressCallback)
         else:
             default.Script.sayAll(self, inputEvent)
@@ -361,7 +358,7 @@ class Script(default.Script):
                                event,
                                event.source.toString())
 
-        # util.printAncestry(event.source)
+        # self.printAncestry(event.source)
 
         # 1) Mail view: current message pane: individual lines of text.
         #
@@ -379,18 +376,18 @@ class Script(default.Script):
         rolesList = [rolenames.ROLE_TEXT, \
                      rolenames.ROLE_PANEL, \
                      rolenames.ROLE_UNKNOWN]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail view: " \
                           + "current message pane: " \
                           + "individual lines of text.")
 
             [string, caretOffset, startOffset] = \
-                util.getTextLineAtCaret(event.source)
+                self.getTextLineAtCaret(event.source)
             braille.displayMessage(string)
             if settings.enableSpeechIndentation:
                 self.speakTextIndentation(event.source, string)
-            line = util.adjustForRepeats(string)
+            line = self.adjustForRepeats(string)
                 
             if self.speakNewLine(event.source):
                 speech.speak(chnames.getCharacterName("\n"), None, False)
@@ -427,7 +424,7 @@ class Script(default.Script):
                      rolenames.ROLE_PANEL, \
                      rolenames.ROLE_TABLE_CELL]
         if settings.readTableCellRow \
-            and (util.isDesiredFocusedItem(event.source, rolesList)):
+            and (self.isDesiredFocusedItem(event.source, rolesList)):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail view: " \
                           + "current message pane: " \
@@ -449,7 +446,7 @@ class Script(default.Script):
                     if cell.role == rolenames.ROLE_TEXT:
                         regions.append(braille.Text(cell))
                         [string, caretOffset, startOffset] = \
-                            util.getTextLineAtCaret(cell)
+                            self.getTextLineAtCaret(cell)
                         utterances.append(string)
 
                 braille.displayRegions([regions, regions[0]])
@@ -478,7 +475,7 @@ class Script(default.Script):
         rolesList = [rolenames.ROLE_TABLE_CELL, \
                      rolenames.ROLE_TREE_TABLE]
         if settings.readTableCellRow \
-            and (util.isDesiredFocusedItem(event.source, rolesList)):
+            and (self.isDesiredFocusedItem(event.source, rolesList)):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail view: " \
                           + "message header list.")
@@ -542,6 +539,13 @@ class Script(default.Script):
                     # is, then to reduce verbosity, only speak and braille it,
                     # if it's checked or if we are moving the focus from to the
                     # left or right on the same row.
+                    #
+                    # The one exception to the above is if this is for the
+                    # Status checkbox, in which case we speake/braille it if
+                    # the message is unread (not checked).
+                    #
+                    header_obj = parent.table.getColumnHeader(i)
+                    header = atspi.Accessible.makeAccessible(header_obj)
 
                     checkbox = False
                     toRead = True
@@ -552,16 +556,18 @@ class Script(default.Script):
                                 checkbox = True
                                 checked = cell.state.count( \
                                     atspi.Accessibility.STATE_CHECKED)
-                                if not checked and speakAll:
-                                    toRead = False
+                                if speakAll:
+                                    if header.name == _("Status"):
+                                        toRead = not checked
+                                        break
+                                    if not checked:
+                                        toRead = False
                                 break
 
                     if toRead:
-                        obj = parent.table.getColumnHeader(i)
-                        header = atspi.Accessible.makeAccessible(obj)
-
                         # Speak/braille the column header for this table cell
                         # if it has focus (unless it's a checkbox).
+                        #
                         if not checkbox and verbose:
                             settings.brailleVerbosityLevel = \
                                 settings.VERBOSITY_LEVEL_BRIEF
@@ -599,7 +605,7 @@ class Script(default.Script):
                                            brailleGen.getBrailleRegions(cell)
 
                         if header.name == _("Status"):
-                            text = _("Read")
+                            text = _("unread")
                             utterances = [ text ]
                             brailleRegions.append(braille.Region(text))
                             brailleRegions.append(braille.Region(" "))
@@ -653,7 +659,7 @@ class Script(default.Script):
 
         rolesList = [rolenames.ROLE_CALENDAR_EVENT, \
                      rolenames.ROLE_CALENDAR_VIEW]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - calendar view: " \
                           + "day view: tabbing to day with appts.")
@@ -720,7 +726,7 @@ class Script(default.Script):
         rolesList = [rolenames.ROLE_UNKNOWN, \
                      rolenames.ROLE_TABLE, \
                      rolenames.ROLE_CALENDAR_VIEW]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                       "evolution.locusOfFocusChanged - calendar view: " \
                       + "day view: moving with arrow keys.")
@@ -797,7 +803,7 @@ class Script(default.Script):
                      rolenames.ROLE_TABLE, \
                      rolenames.ROLE_UNKNOWN, \
                      rolenames.ROLE_SCROLL_PANE]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                       "evolution.locusOfFocusChanged - preferences dialog: " \
                       + "table cell in options list.")
@@ -832,7 +838,7 @@ class Script(default.Script):
                      rolenames.ROLE_FILLER, \
                      rolenames.ROLE_FILLER, \
                      rolenames.ROLE_DIALOG]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail insert " \
                           + "attachment dialog: unlabelled button.")
@@ -860,7 +866,7 @@ class Script(default.Script):
                      rolenames.ROLE_PANEL, \
                      rolenames.ROLE_PANEL, \
                      rolenames.ROLE_SCROLL_PANE]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - mail " \
                           + "compose window: message area.")
@@ -892,7 +898,7 @@ class Script(default.Script):
                     rolenames.ROLE_PANEL, \
                     rolenames.ROLE_FILLER, \
                     rolenames.ROLE_DIALOG]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                       "evolution.locusOfFocusChanged - spell checking dialog.")
 
@@ -905,18 +911,18 @@ class Script(default.Script):
             # misspelt word.
             #
             panel = event.source.parent.parent
-            allLabels = util.findByRole(panel, rolenames.ROLE_LABEL)
+            allLabels = self.findByRole(panel, rolenames.ROLE_LABEL)
             found = False
-            for i in range(0, len(allLabels)):
+            for label in allLabels:
                 if not found:
-                    text = util.getDisplayedText(allLabels[i])
+                    text = self.getDisplayedText(label)
                     if text:
                         tokens = text.split()
                     else:
                         tokens = []
-                    for j in range(0, len(tokens)):
-                        if tokens[j].startswith("'"):
-                            badWord = tokens[j]
+                    for token in tokens:
+                        if token.startswith("'"):
+                            badWord = token
                             badWord = badWord[1:len(badWord)-1]
                             found = True
                             break
@@ -928,13 +934,13 @@ class Script(default.Script):
             if self.message_panel != None:
                 allTokens = []
                 panel = self.message_panel
-                allText = util.findByRole(panel, rolenames.ROLE_TEXT)
+                allText = self.findByRole(panel, rolenames.ROLE_TEXT)
                 for i in range(0, len(allText)):
                     text = self.getText(allText[i], 0, -1)
                     tokens = text.split()
                     allTokens += tokens
 
-                util.speakMisspeltWord(allTokens, badWord)
+                self.speakMisspeltWord(allTokens, badWord)
                 return
 
         # 10) Mail view: message area - attachments.
@@ -958,7 +964,7 @@ class Script(default.Script):
                     rolenames.ROLE_TABLE_CELL, \
                     rolenames.ROLE_TABLE, \
                     rolenames.ROLE_PANEL]
-        if util.isDesiredFocusedItem(event.source, rolesList):
+        if self.isDesiredFocusedItem(event.source, rolesList):
             debug.println(self.debugLevel,
                           "evolution.locusOfFocusChanged - " \
                           + "mail message area attachments.")
@@ -970,7 +976,7 @@ class Script(default.Script):
 
             table = event.source.parent.parent.parent.parent.parent
             cell = table.child(table.childCount-1)
-            allText = util.findByRole(cell, rolenames.ROLE_TEXT)
+            allText = self.findByRole(cell, rolenames.ROLE_TEXT)
             utterance = "for " + self.getText(allText[0], 0, -1)
             speech.speak(utterance)
             return
