@@ -27,9 +27,9 @@ The following script specific key sequences are supported:
   Insert-[1-9]  -  Speak and braille a previous chat room message.
 """
 
-__id__        = "$Id: gaim.py,v 1.23 2006/09/29 17:02:23 wwalker Exp $"
-__version__   = "$Revision: 1.23 $"
-__date__      = "$Date: 2006/09/29 17:02:23 $"
+__id__        = "$Id: gaim.py 2140 2007-03-07 20:04:06Z richb $"
+__version__   = "$Revision: 2140 $"
+__date__      = "$Date: 2007-03-07 15:04:06 -0500 (Wed, 07 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -42,7 +42,6 @@ import orca.keybindings as keybindings
 import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
-import orca.util as util
 
 from orca.orca_i18n import _
 
@@ -173,10 +172,10 @@ class Script(default.Script):
                 self.inputEventHandlers["togglePrefixHandler"]))
 
         messageKeys = [ "1", "2", "3", "4", "5", "6", "7", "8", "9" ]
-        for i in range(0, len(messageKeys)):
+        for messageKey in messageKeys:
             keyBindings.add(
                 keybindings.KeyBinding(
-                    messageKeys[i],
+                    messageKey,
                     1 << settings.MODIFIER_ORCA,
                     1 << settings.MODIFIER_ORCA,
                     self.inputEventHandlers["readPreviousMessageHandler"]))
@@ -305,7 +304,7 @@ class Script(default.Script):
             # text field. Hopefully this is true for other types of chat
             # as well, but is currently untested.
             #
-            allTextFields = util.findByRole(chatRoomTab,
+            allTextFields = self.findByRole(chatRoomTab,
                                             rolenames.ROLE_TEXT)
             index = len(allTextFields) - 2
             if index >= 0:
@@ -327,7 +326,7 @@ class Script(default.Script):
             if message and message[0] == "\n":
                 message = message[1:]
 
-            chatRoomName = util.getDisplayedText(chatRoomTab)
+            chatRoomName = self.getDisplayedText(chatRoomTab)
             self.utterMessage(chatRoomName, message)
 
             # Add the latest message to the list of saved ones. For each
