@@ -23,9 +23,9 @@ class.  For those wishing to override the speech generators, however,
 one can create a new instance and replace/extend the speech generators
 as they see fit."""
 
-__id__        = "$Id: speechgenerator.py 1933 2007-01-17 19:32:35Z wwalker $"
-__version__   = "$Revision: 1933 $"
-__date__      = "$Date: 2007-01-17 14:32:35 -0500 (Wed, 17 Jan 2007) $"
+__id__        = "$Id: speechgenerator.py 2126 2007-03-06 21:35:17Z richb $"
+__version__   = "$Revision: 2126 $"
+__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -36,7 +36,6 @@ import debug
 import orca_state
 import rolenames
 import settings
-import util
 
 from orca_i18n import _                          # for gettext support
 
@@ -166,7 +165,7 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken.
         """
 
-        result = util.getAcceleratorAndShortcut(obj)
+        result = self._script.getAcceleratorAndShortcut(obj)
 
         accelerator = result[0]
         #shortcut = result[1]
@@ -200,14 +199,14 @@ class SpeechGenerator:
             return []
 
     def _getSpeechForObjectLabel(self, obj):
-        label = util.getDisplayedLabel(obj)
+        label = self._script.getDisplayedLabel(obj)
         if label:
             return [label]
         else:
             return []
 
     def _getSpeechForObjectName(self, obj):
-        name = util.getDisplayedText(obj)
+        name = self._script.getDisplayedText(obj)
         if name:
             return [name]
         elif obj.description:
@@ -301,7 +300,7 @@ class SpeechGenerator:
 
         # Find all the unrelated labels in the dialog and speak them.
         #
-        labels = util.findUnrelatedLabels(obj)
+        labels = self._script.findUnrelatedLabels(obj)
         for label in labels:
             utterances.append(label.name)
 
@@ -815,7 +814,7 @@ class SpeechGenerator:
         if obj.role != rolenames.ROLE_PARAGRAPH:
             utterances.extend(self._getSpeechForObjectRole(obj))
 
-        [text, caretOffset, startOffset] = util.getTextLineAtCaret(obj)
+        [text, caretOffset, startOffset] = self._script.getTextLineAtCaret(obj)
         utterances.append(text)
 
         self._debugGenerator("_getSpeechForText",
@@ -1066,7 +1065,7 @@ class SpeechGenerator:
         try:
             minimumIncrement = value.minimumIncrement
         except:
-            pass
+            minimumIncrement = 0.0
 
         if minimumIncrement == 0.0:
             minimumIncrement = (value.maximumValue - value.minimumValue) \
@@ -1130,7 +1129,7 @@ class SpeechGenerator:
         """
 
         if already_focused:
-            utterances = [util.getDisplayedText(obj)]
+            utterances = [self._script.getDisplayedText(obj)]
         else:
             utterances = self._getDefaultSpeech(obj, already_focused)
 
@@ -1220,8 +1219,8 @@ class SpeechGenerator:
                     obj.role = rolenames.ROLE_TABLE_CELL
                     break
 
-        utterances.append(util.getDisplayedText(\
-                          util.getRealActiveDescendant(obj)))
+        utterances.append(self._script.getDisplayedText(\
+                          self._script.getRealActiveDescendant(obj)))
 
         # [[[TODO: WDW - HACK attempt to determine if this is a node;
         # if so, describe its state.]]]
@@ -1372,11 +1371,11 @@ class SpeechGenerator:
         """
 
         title = None
-        frame = util.getFrame(obj)
+        frame = self._script.getFrame(obj)
         if frame:
             title = frame.name
         if not title:
-            title = util.getDisplayedLabel(obj)
+            title = self._script.getDisplayedLabel(obj)
 
         utterances = [title]
 
@@ -1572,8 +1571,8 @@ class SpeechGenerator:
 
                 # Announce the label and text of the object in the hierarchy.
                 #
-                text = util.getDisplayedText(parent)
-                label = util.getDisplayedLabel(parent)
+                text = self._script.getDisplayedText(parent)
+                label = self._script.getDisplayedLabel(parent)
 
                 # Push announcement of cell after text and label.
                 #
@@ -1597,7 +1596,7 @@ class SpeechGenerator:
             # we add the label to the overall context.]]]
             #
             if parent.role == rolenames.ROLE_FILLER:
-                label = util.getDisplayedLabel(parent)
+                label = self._script.getDisplayedLabel(parent)
                 if label and len (label):
                     utterances.append(label)
 
